==> react-use-9.4.1.tgz: package/esm/useMap.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { useState } from 'react';
var useMap = function (initialMap) {
    if (initialMap === void 0) { initialMap = {}; }
    var _a = useState(initialMap), map = _a[0], set = _a[1];
    return [
        map,
        {
            get: function (key) { return map[key]; },
            set: function (key, entry) {
                var _a;
                set(__assign({}, map, (_a = {}, _a[key] = entry, _a)));
            },
            remove: function (key) {
                var _a = key, omit = map[_a], rest = __rest(map, [typeof _a === "symbol" ? _a : _a + ""]);
                set(rest);
            },
            reset: function () { return set(initialMap); },
        },
    ];
};
export default useMap;

==> react-use-9.11.0.tgz: package/esm/useMap.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { useState } from 'react';
var useMap = function (initialMap) {
    if (initialMap === void 0) { initialMap = {}; }
    var _a = useState(initialMap), map = _a[0], set = _a[1];
    return [
        map,
        {
            get: function (key) { return map[key]; },
            set: function (key, entry) {
                set(function (prevMap) {
                    var _a;
                    return (__assign({}, prevMap, (_a = {}, _a[key] = entry, _a)));
                });
            },
            remove: function (key) {
                set(function (prevMap) {
                    var _a = key, omit = prevMap[_a], rest = __rest(prevMap, [typeof _a === "symbol" ? _a : _a + ""]);
                    return rest;
                });
            },
            reset: function () { return set(initialMap); },
        },
    ];
};
export default useMap;
